@@ -1,7 +1,5 @@
 import pandas as pd
 def topsis(df,weights,impacts):
-    df1=pd.DataFrame()
-    df1=df.copy()
     vjp=[]
     vjn=[]
     r=df.shape[0]
@@ -25,6 +23,6 @@ def topsis(df,weights,impacts):
     for i in range(r):
         df.loc[i,'sj-']=sum((df.iloc[i,1:c]-vjn)**2)**0.5
 # print(df)
-    df1['Topsis Score']=round(df['sj-']/(df['sj+']+df['sj-']),2)
-    df1['Rank']=df['Topsis Score'].rank(ascending=False).astype('int')
-    return df1
\ No newline at end of file
+    df['Topsis Score']=round(df['sj-']/(df['sj+']+df['sj-']),2)
+    df['Rank']=df['Topsis Score'].rank(ascending=False).astype('int')
+    return df
\ No newline at end of file
